pyxmpp.sasl.core.Response

Package pyxmpp :: Package sasl :: Module core :: Class Response |
[hide private]

# Class Response

source code

    Reply --+
            |
           Response

The response SASL message (clients's reply the the server's challenge).

Instance Methods | [hide private]
__init__(self, data=`'````'`) Initialize the Response object. | source code
__repr__(self) | source code
Inherited from `Reply`: `base64`

Instance Variables | [hide private]
Inherited from `Reply`: `data`

Method Details | [hide private]

### __init__(self, data=`'````'`) (Constructor) | source code
Initialize the Response object. Parameters: `data` - optional reply data. Overrides: Reply.__init__